<?php
/**
 * @file
 * Theme functions for user generated content module.
 */

/**
 * Theme loading message for UGC project.
 *
 * @param string $message
 *   Message to display to user.
 * @param boolean $error
 *   Is error.
 */
function theme_ugc_loading_message($message, $error) {
  return 'LOAD ERROR';
}

/**
 * Theme summary of UGC project.
 *
 * @param object $project
 *   Node object for UGC project record.
 */
function theme_ugc_project_summary($project) {
  $html = '<h2>' . $project->title . '</h2>';
  if (!empty($project->body)) {
    $html .= '<div>' . $project->body . '</div>';
  }
  return $html;
}

/**
 * Theme UGC project closed message.
 *
 * @param object $project
 *   Node object for UGC project record.
 */
function theme_ugc_project_closed($project) {
  return 'CLOSED';
}

/**
 * Theme user access denied to create UGC content message.
 *
 * @param object $project
 *   Node object for UGC project record.
 * @param object $user
 *   Logged in user record.
 */
function theme_ugc_access_denied($project, $user) {
  return 'NO ACCESS';
}

/**
 * Theme user not logged in message.
 *
 * @param object $project
 *   Node object for UGC project record.
 */
function theme_ugc_user_not_logged_in($project) {
  return 'NOT LOGGED IN';
}

/**
 * Theme UGC form output.
 *
 * @param string $form
 *   HTML for form element.
 * @param string $node_type
 *   Node type defining form.
 */
function theme_ugc_form($form, $node_type) {
  return $form;
}

/**
 * Theme a UGC field that is allowed multiple values.
 *
 * @param array $element
 *   Multi value field definition.
 */
function theme_ugc_multi_field($element) {
  $html = '';
  // Add defined prefix.
  if (!empty($element['#prefix'])) {
    $html .= $elememt['#prefix'];
  }
  // Add field title.
  if (!empty($element['#title'])) {
    $html .= '<div><strong>' . $element['#title'] . '</strong></div>';
  }
  // Render field form elements.
  $html .= drupal_render($element);
  if (!empty($element['#description'])) {
    $html .= '<div class="description">' . $element['#description'] . '</div>';
  }
  // Add defined suffix.
  if (!empty($element['#suffix'])) {
    $html .= $element['#suffix'];
  }
  return $html;
}

/**
 * Theme a UGC taxonomy field.
 *
 * @param array $element
 *   Taxonomy field definition.
 */
function theme_ugc_field_taxonomy($element) {
    $html = '';
  // Add field title.
  if (!empty($element['#title'])) {
    $html .= '<div><strong>' . $element['#title'] . '</strong></div>';
  }
  // Render field form elements.
  $html .= drupal_render($element);
  return $html;
}
